/*   
*   Example of One Patching
*   -----------------------
*
*   Applies the operator to a dataset, either
*   forward or adjoint, depending on adj.
*/
#include <foponepatch.h> 
#include <SEPinit.h>

#include <Process.h>
#include <Axis.h>
main(int argc,char **argv) {
    
    // SEPLIB initialization & initialize stdin
    SepInput * sepInput = SEPinit( argc, argv, SOURCE );
    
    // Check that we are getting floating point data
    if( sepInput->Info()->Esize() !=4 ) 
      seperr("esize !=4, expecting floating point data \n");
    
    // Get the forward/adjoint and test flags from the command line
    int adj=0; sepInput->Getch( "adj", adj );
    
    SepData * inData = new SepData(sepInput);
    
    // convert to Space
    floatspace space( inData );
    Axislist axes = space.getaxislist();
//------------------------------------------------------
    //make Patching operator
    float org1=.012; sepInput->Getch( "org1", org1 );
    float org2=.6; sepInput->Getch( "org2", org2 );
    int size1=4; sepInput->Getch( "size1", size1 );
    int size2=7; sepInput->Getch( "size2", size2 );


    fopOnepatch op( 0,10,0,20,axes );
    fopOnepatch op1( axes, org1, size1, org2, size2 );

//------------------------------------------------------

    // process each plane and write to stdout
    if (adj)
      Process(sepInput , op, adj );
    else
      Process(sepInput , op1, adj );
    
    // clean up
    UnRef(sepInput);
    
    return 0;

}
