/*   
*   Example of Patching
*   -------------------
*
*   Patch <data.H  >data2.H scale=3 adj=0 num1=3 num2=3 size1=5 size2=8
*
*   Applies the operator to a dataset, either
*   forward or adjoint, depending on adj.
*
*   The operator used here patches the space, scales the
*   dataset by a float, and unpatches it if test=0.  If 
*   test=1, one patch is scaled by scale * 2 instead of scale.
*/
#include <foparray.h>

#include <fopdiagonal.h>
#include <fopchain.h>
#include <fopadjoint.h>

#include <foppatch.h> 
#include <fopscale.h>
#include <fopunpatch.h>

#include <SEPinit.h>

#include <Process.h>

main(int argc,char **argv) {
    
    // SEPLIB initialization & initialize stdin
    SepInput * sepInput = SEPinit( argc, argv, SOURCE );
    
    // Check that we are getting floating point data
    if( sepInput->Info()->Esize() !=4 ) 
      seperr("esize !=4, expecting floating point data \n");
    
    // Get the forward/adjoint and test flags from the command line
    int adj=0; sepInput->Getch( "adj", adj );
    
    SepData * inData = new SepData(sepInput);
    
    // convert to Space
    floatspace space( inData );
    Axislist axes = space.getaxislist();
//------------------------------------------------------
    //make Patching operator
    int num1=3; sepInput->Getch( "num1", num1 );
    int num2=3; sepInput->Getch( "num2", num2 );
    int size1=4; sepInput->Getch( "size1", size1 );
    int size2=7; sepInput->Getch( "size2", size2 );
    fopPatch patch( num1, num2, size1, size2, axes );
    
    // construct scaling operators
    float scale=3; sepInput->Getch( "scale", scale );
    fopScale opscale( 0.5 );
    fopScale opscale2( scale );

    // construct diagonal fopArray of scaling operators
    fopDiagonal diagonal( num1*num2, opscale );

    // individual operators can also be set: 
    diagonal.set( 4 , opscale2 );

    // make operator for patching with weighting
    fopUnpatch unpatch( patch );
    
    // op=(fopUnpatch.Adjoint(diagonal*fopPatch.Forward(space)))
    fopChain op = !unpatch * diagonal * patch;
//------------------------------------------------------

    // process each plane and write to stdout
    Process(sepInput , op, adj );
    
    // clean up
    UnRef(sepInput);
    
    return 0;

}
