/*   
*   Example of Patching
*   -------------------
*
*   Patch <data.H  >data2.H scale=3 adj=0 num1=3 num2=3 size1=5 size2=8
*
*   Applies the operator to a dataset, either
*   forward or adjoint, depending on adj.
*
*   The operator used here patches the space, scales the
*   dataset by a float, and unpatches it if test=0.  If 
*   test=1, one patch is scaled by scale * 2 instead of scale.
*/
#include <foparray.h>

#include <foppatch.h> 

#include <SEPinit.h>

#include <Process.h>

main(int argc,char **argv) {
    
    // SEPLIB initialization & initialize stdin
    SepInput * sepInput = SEPinit( argc, argv, SOURCE );
    
    // Check that we are getting floating point data
    if( sepInput->Info()->Esize() !=4 ) 
      seperr("esize !=4, expecting floating point data \n");
    
    // Get the forward/adjoint and test flags from the command line
    int adj=0; sepInput->Getch( "adj", adj );
    
    SepData * inData = new SepData(sepInput);
    
    // convert to Space
    floatspace space( inData );
    Axislist axes = space.getaxislist();
//------------------------------------------------------
    //make Patching operator

    int num1=3; sepInput->Getch( "num1", num1 );
    int num2=3; sepInput->Getch( "num2", num2 );
    int size1=4; sepInput->Getch( "size1", size1 );
    int size2=7; sepInput->Getch( "size2", size2 );
    fopPatch patch( num1, num2, size1, size2, axes );
    
    floatspacearray outspacearray = patch.Forward(space);
 
   	// convert output back to SepPlane
    SepData * outData = (outspacearray(0,0)).sepData();
	// seismic output
    SepOutput *sepOut = new SepOutput("./patches/p0.H",outData);
    delete outData;
    delete sepOut;

   	// convert output back to SepPlane
    outData = (outspacearray(1,0)).sepData();
	// seismic output
    sepOut = new SepOutput("./patches/p1.H",outData);
    delete outData;
    delete sepOut;

   	// convert output back to SepPlane
    outData = (outspacearray(2,0)).sepData();
	// seismic output
    sepOut = new SepOutput("./patches/p2.H",outData);
    delete outData;
    delete sepOut;

   	// convert output back to SepPlane
    outData = (outspacearray(3,0)).sepData();
	// seismic output
    sepOut = new SepOutput("./patches/p3.H",outData);
    delete outData;
    delete sepOut;

   	// convert output back to SepPlane
    outData = (outspacearray(4,0)).sepData();
	// seismic output
    sepOut = new SepOutput("./patches/p4.H",outData);
    delete outData;
    delete sepOut;

   	// convert output back to SepPlane
    outData = (outspacearray(5,0)).sepData();
	// seismic output
    sepOut = new SepOutput("./patches/p5.H",outData);
    delete outData;
    delete sepOut;

   	// convert output back to SepPlane
    outData = (outspacearray(6,0)).sepData();
	// seismic output
    sepOut = new SepOutput("./patches/p6.H",outData);
    delete outData;
    delete sepOut;

   	// convert output back to SepPlane
    outData = (outspacearray(7,0)).sepData();
	// seismic output
    sepOut = new SepOutput("./patches/p7.H",outData);
    delete outData;
    delete sepOut;

   	// convert output back to SepPlane
    outData = (outspacearray(8,0)).sepData();
	// seismic output
    sepOut = new SepOutput("./patches/p8.H",outData);

    delete sepOut;
    sepOut = new SepOutput("stdout",outData);

    delete outData;
    delete sepOut;


//------------------------------------------------------
    
    // clean up
    UnRef(sepInput);
    
    return 0;

}
